@@ -6,7 +6,7 @@
 
 import sys
 from typing import Dict, Any, Iterator
-from python_workflow_plugin_framework.core.base_plugin import BasePluginService, serve_plugin
+from python_workflow_plugin_framework.base_plugin import BasePluginService, serve_plugin
 
 
 class TextProcessorPlugin(BasePluginService):
